gdext-async 0.1.1

Async utilities for inter-operating between Rust and GDScript code
docs.rs failed to build gdext-async-0.1.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: gdext-async-0.1.2